@@ -1,7 +1,7 @@
 from typing import Any, TypeVar
 
+import aiohttp
 import orjson
-from aiohttp import ClientSession, DummyCookieJar
 from aiohttp.payload import BytesPayload
 
 from ..__version__ import __version__
@@ -14,7 +14,7 @@ from ._requests import (
     RestApiRequest,
     UpdateRecordRestApiRequest,
 )
-from .exceptions import UnexpectedRestApiResponsePayload
+from .exceptions import ClientError, UnexpectedRestApiResponsePayload
 from .record import Record, RecordQueryResult
 from .reference_id import ReferenceId
 from .unit_of_work import UnitOfWork
@@ -28,7 +28,8 @@ class DataAPI:
     """
     Data API client to interact with data in a Salesforce org.
 
-    A preconfigured instance of this client is provided at `context.org.data_api`.
+    We provide a preconfigured instance of this client at `context.org.data_api`
+    to make it easier for you to query, insert, and update records.
 
     For example:
 
@@ -45,7 +46,7 @@ class DataAPI:
         org_domain_url: str,
         api_version: str,
         access_token: str,
-        session: ClientSession | None = None,
+        session: aiohttp.ClientSession | None = None,
     ) -> None:
         self._api_version = api_version
         self._org_domain_url = org_domain_url
@@ -66,8 +67,8 @@ class DataAPI:
             # ...
         ```
 
-        If the returned `RecordQueryResult`'s `done` attribute is `False`, then it indicates that
-        there are more records to be returned. To retrieve these, use `DataAPI.query_more()`.
+        If the returned `RecordQueryResult`'s `done` attribute is `False`, there are more
+        records to be returned. To retrieve these, use `DataAPI.query_more()`.
 
         For more information, see the [Query REST API documentation](https://developer.salesforce.com/docs/atlas.en-us.api_rest.meta/api_rest/resources_query.htm).
         """  # noqa: E501 pylint: disable=line-too-long
@@ -151,7 +152,7 @@ class DataAPI:
 
     async def delete(self, object_type: str, record_id: str) -> str:
         """
-        Delete an existing record of the given type and id.
+        Delete an existing record of the given Salesforce object type and ID.
 
         Returns the ID of the record that was deleted.
 
@@ -167,7 +168,7 @@ class DataAPI:
         self, unit_of_work: UnitOfWork
     ) -> dict[ReferenceId, str]:
         """
-        Commit a `UnitOfWork`, executing all operations registered with it.
+        Commit a `UnitOfWork`, which executes all operations registered with it.
 
         If any of these operations fail, the whole unit is rolled back. To examine results for a
         single operation, inspect the returned dict (which is keyed with `ReferenceId` objects
@@ -208,7 +209,7 @@ class DataAPI:
         method: str = rest_api_request.http_method()
         body = rest_api_request.request_body()
 
-        session = self._shared_session or ClientSession()
+        session = self._shared_session or _create_session()
 
         try:
             response = await session.request(
@@ -226,8 +227,15 @@ class DataAPI:
             # - Orjson's performance/memory usage is better if it is passed bytes directly instead of `str`.
             response_body = await response.read()
             json_body = orjson.loads(response_body) if response_body else None
+        except aiohttp.ClientError as e:
+            # https://docs.aiohttp.org/en/stable/client_reference.html#client-exceptions
+            raise ClientError(
+                f"An error occurred while making the request: {e.__class__.__name__}: {e}"
+            ) from e
         except orjson.JSONDecodeError as e:
-            raise UnexpectedRestApiResponsePayload() from e
+            raise UnexpectedRestApiResponsePayload(
+                f"The server didn't respond with valid JSON: {e.__class__.__name__}: {e}"
+            ) from e
         finally:
             if session != self._shared_session:
                 await session.close()
@@ -254,11 +262,11 @@ class DataAPI:
         }
 
 
-def _create_session() -> ClientSession:
+def _create_session() -> aiohttp.ClientSession:
     # Disable cookie storage using `DummyCookieJar`, given that:
     # - The same session will be used by multiple invocation events.
     # - We don't need cookie support.
-    return ClientSession(cookie_jar=DummyCookieJar())
+    return aiohttp.ClientSession(cookie_jar=aiohttp.DummyCookieJar())
 
 
 def _json_serialize(data: Any) -> BytesPayload:
